==> ntch-1.0.2.2.tgz: ntch-1.0.2.2/nce/nc_delete_attribute_db.php <==
<?php
/*
 nce (ntch cloud environment.)
 name: nc_update_readcnt_db.php
 author: Akira Ohta (akohta001.gmail.com)
 date: 2013-apr-14th
 description:
 License: GPLv3
 */
include_once "account.php";
include_once "preference.php";
include_once "database.php";
include_once "log.php";
include_once "http_util.php";
include_once "error_code.php";

$user_id = $_POST['user'];
$hashed_passwd = $_POST['hashed_passwd'];
$board_name = $_POST['board_name'];
$dat_name = $_POST['dat_name'];
$res_number = $_POST['res_number'];
$record_type = $_POST['record_type'];

//--- authorization ---
$user = chk_passwd( $user_id, $hashed_passwd);
if(FALSE === $user){
	echo $ERROR_MSG;
	exit;
}

//--- parameter check start ---
if(!chk_param($board_name) || !chk_param($dat_name) ||
	!chk_param($res_number) || !chk_param($record_type)){
	echo ERROR303;
	exit;
}

if(!is_numeric($record_type) && '*' != $record_type){
	echo ERROR303;
	exit;
}
//--- parameter check end ---


$table_name = TABLE_PREFIX."tbl{$user->home_dir}";
$error_msg;
$query = "delete from $table_name where board_name='{$board_name}' ";
if('*' != $dat_name){
	$query = $query."and dat_name='{$dat_name}' ";
	if('*' != $res_number){
		$query = $query."and res_number='{$res_number}' ";
		if('*' != $record_type){
			$query = $query."and record_type={$record_type} ";
		}
	}
}

try{
	$db->open();
	$result = $db->execute($query);
	if(!$result){
		echo  ERROR504;
		exit;
	}
	$db->close();
}catch(Exception $e){
	$error = __FILE__."(".__LINE__.
		") An error occured during delete.";
	
	nc_logging($error, $e);
	echo ERROR500;
	exit;
}

echo SUCCESS100;

?>

==> ntch-1.0.2.6.tgz: ntch-1.0.2.6/nce/nc_delete_attribute_db.php <==
<?php
/*
 nce (ntch cloud environment.)
 name: nc_update_readcnt_db.php
 author: Akira Ohta (akohta001.gmail.com)
 date: 2013-apr-14th
 description:
 License: GPLv3
 */
include_once "account.php";
include_once "preference.php";
include_once "database.php";
include_once "log.php";
include_once "http_util.php";
include_once "error_code.php";

$user_id = $_POST['user'];
$token = $_POST['token'];
$board_name = $_POST['board_name'];
$dat_name = $_POST['dat_name'];
$res_number = $_POST['res_number'];
$record_type = $_POST['record_type'];

//--- authorization ---
$user = chk_passwd( $user_id, $token);
if(FALSE === $user){
	echo $ERROR_MSG;
	exit;
}

//--- parameter check start ---
if(!chk_param($board_name) || !chk_param($dat_name) ||
	!chk_param($res_number) || !chk_param($record_type)){
	echo ERROR303;
	exit;
}

if(!is_numeric($record_type) && '*' != $record_type){
	echo ERROR303;
	exit;
}
//--- parameter check end ---


$table_name = TABLE_PREFIX."tbl{$user->home_dir}";
$error_msg;
$query = "delete from $table_name where board_name='{$board_name}' ";
if('*' != $dat_name){
	$query = $query."and dat_name='{$dat_name}' ";
	if('*' != $res_number){
		$query = $query."and res_number='{$res_number}' ";
		if('*' != $record_type){
			$query = $query."and record_type={$record_type} ";
		}
	}
}

try{
	$db->open();
	$result = $db->execute($query);
	if(!$result){
		echo  ERROR504;
		exit;
	}
	$db->close();
}catch(Exception $e){
	$error = __FILE__."(".__LINE__.
		") An error occured during delete.";
	
	nc_logging($error, $e);
	echo ERROR500;
	exit;
}

echo SUCCESS100;

?>
